package tech.bitgoblin.config;

import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;

import org.apache.commons.cli.*;

import tech.bitgoblin.Logger;
import tech.bitgoblin.io.IOUtils;

public class Cmd {

	private String helpHeader = "Start the Dragoon video transcoder.";
	private String helpFooter = "Report issues at https://git.metaunix.net/BitGoblin/dragoon/issues/";

	private String configPath = "~/.config/dragoon.toml";

	public Cmd(String[] args) throws ParseException {
		Options options = new Options();

		// print help for the user
		Option helpOption = new Option("h", "help", false, "Display CLI usage and options.");
		options.addOption(helpOption);
		
		// install a config file in the user's home directory
		Option installOption = new Option("i", "install", false, "Install configuration file in the user's home directory (or specify a location with -c).");
		options.addOption(installOption);
		
		// allow the user to specify a config file manually
	    Option configPath = new Option("c", "configPath", true, "Configuration file path (defaults to " + this.configPath + ")");
	    configPath.setRequired(false);
	    options.addOption(configPath);
	
	    CommandLineParser parser = new DefaultParser();
	    CommandLine cmd = parser.parse(options, args);
	    
	    // check if the help option was called
	    if (cmd.hasOption("help")) {
	    	this.printHelp(options);
	    }
	    
	    // check if the install option was called
	    if (cmd.hasOption("install")) {
	    	try {
				this.installConfig();
			} catch (IOException e) {
				e.printStackTrace();
				Logger.logger.error("Unable to install new configuration file; please refer to the stack trace above to resolve the error.");
				System.exit(2);
			}
	    }
	
	    // set the configPath variable if the option was passed to the program
	    if (cmd.hasOption("configPath")) {
	    	this.configPath = cmd.getOptionValue("configPath");
	    }
	}

	public void printHelp(Options options) {
		HelpFormatter formatter = new HelpFormatter();
		formatter.printHelp("Dragoon", this.helpHeader, options, this.helpFooter, true);
		
		System.exit(0);
	}
	
	public void installConfig() throws IOException {
		ClassLoader classloader = Thread.currentThread().getContextClassLoader();
		InputStream is = classloader.getResourceAsStream("example.config");
		Files.copy(is, Paths.get(IOUtils.resolveTilda(this.configPath)), StandardCopyOption.REPLACE_EXISTING);
		Logger.logger.info("A new configuration file has been installed at " + this.configPath + ".");
		
		System.exit(0);
	}

	public String getConfigPath() {
		return this.configPath;
	}

}
